==> haskell-gnuidn-0.2.2-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-gnuidn.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gnuidn
version: 0.2.2
id: gnuidn-0.2.2-4ogy9E5NYxkJJWIbk1yEcf
key: gnuidn-0.2.2-4ogy9E5NYxkJJWIbk1yEcf
license: GPL-3
maintainer: jmillikin@gmail.com
stability: experimental
homepage: https://john-millikin.com/software/haskell-gnuidn/
synopsis: Bindings for GNU IDN
category: Codec, Text
author: John Millikin
exposed: True
indefinite: False
exposed-modules:
    Data.Text.IDN.IDNA Data.Text.IDN.Punycode Data.Text.IDN.StringPrep
hidden-modules: Data.Text.IDN.Internal
abi: 784ff3e2fa935e9192674867d573c8e8
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/gnuidn-0.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/gnuidn-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/gnuidn-0.2.2
hs-libraries: HSgnuidn-0.2.2-4ogy9E5NYxkJJWIbk1yEcf
extra-libraries:
    idn idn
depends:
    base-4.10.1.0 text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-gnuidn/html/gnuidn.haddock
haddock-html: /usr/share/doc/haskell-gnuidn/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gnuidn-0.2.2-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-gnuidn.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gnuidn
version: 0.2.2
id: gnuidn-0.2.2-BzrrzGi9rBgLNeehdjt0SF
key: gnuidn-0.2.2-BzrrzGi9rBgLNeehdjt0SF
license: GPL-3
maintainer: jmillikin@gmail.com
stability: experimental
homepage: https://john-millikin.com/software/haskell-gnuidn/
synopsis: Bindings for GNU IDN
category: Codec, Text
author: John Millikin
exposed: True
indefinite: False
exposed-modules:
    Data.Text.IDN.IDNA Data.Text.IDN.Punycode Data.Text.IDN.StringPrep
hidden-modules: Data.Text.IDN.Internal
abi: c6ae0a15f40e93af775be82bdb55067a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/gnuidn-0.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/gnuidn-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/gnuidn-0.2.2
hs-libraries: HSgnuidn-0.2.2-BzrrzGi9rBgLNeehdjt0SF
extra-libraries:
    idn idn
depends:
    base-4.10.1.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    bytestring-0.10.8.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
haddock-interfaces: /usr/share/doc/haskell-gnuidn/html/gnuidn.haddock
haddock-html: /usr/share/doc/haskell-gnuidn/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
